@@ -1,6 +1,7 @@
-from datetime import datetime, timedelta, timezone
+from datetime import datetime, timedelta
 
 from django.db import models
+from django.utils import timezone
 
 from .token import TokenMixin
 
